@@ -188,7 +188,7 @@ class LibraryExperiment(object):
             self.count_mat = filtered_count_mat
             
         # normalized count matrix to counts per million
-        normalized_count_mat = self.count_mat
+        normalized_count_mat = self.count_mat.copy()
         counts = normalized_count_mat[self.pools].values.astype(float)
         counts = (counts/np.sum(counts, axis=0))*1e6
         normalized_count_mat[self.pools] = counts
@@ -198,7 +198,7 @@ class LibraryExperiment(object):
         # apply count filters to reduce noise
         counts = global_filter_counts(counts, thr=self.global_filter_thr)
         counts = local_filter_counts(counts, thr=self.filter_thr)
-        filtered_count_mat = normalized_count_mat
+        filtered_count_mat = normalized_count_mat.copy()
         filtered_count_mat[self.pools] = counts
         self.filtered_count_mat = filtered_count_mat
         
@@ -208,19 +208,6 @@ class LibraryExperiment(object):
         genes names.
         
         """
-        # normalize to library size and filter low reads
-        filtered_count_mat = self.count_mat
-        counts = filtered_count_mat[self.pools].values.astype(float)
-        counts = (counts/np.sum(counts, axis=0))*1e6
-        filtered_count_mat[self.pools] = counts
-
-        self.normalized_count_mat = filtered_count_mat
-
-        counts = global_filter_counts(counts, thr=self.global_filter_thr)
-        counts = local_filter_counts(counts, thr=self.filter_thr)
-        filtered_count_mat[self.pools] = counts
-        self.filtered_count_mat = filtered_count_mat
-        
 
         unambiguous_data, ambiguous_data= get_ambiguity(self)
         unambiguous_locations =  get_unambiguous_locations(unambiguous_data, self)
